// Makes all Figures and Tables and 
// Created by Jake Weber 8/3/2022 (cf: 11e_figures_for_JMCBpaper_v3 except as noted)
cls; set more off; clear
use final_paper_tradingdays, clear 

//////////// PLEASE READ CLOSELY: //////////////////////////////////////////
version 15.1 // set stata version to the version we used in the paper
* ssc install lassopack // installs latest version of lassopack (1.4.1). You will likely need to install this!
// Later versions of stata have built in lasso compatibility but they may not deliver the same results if they have
// different default settings. 
* ssc install estout    // the code makes use of esttab and will fail if this package is not installed
/////////////////////////////////////////////////////////////////////////////

////////////////////// Paper Figures 1 and 2 //////////////////////
tsset date
// most interventions are small
tsline int_base_frac if date < 2877 | date > 2881 ,  graphregion(color(white)) note("Omits three outliers of >10% surrounding Nov. 1967 Devaluation") ///
xtitle("") ytitle("") title("Intervention over Time: Sales of Dollars as a % of M0" , size(med)) xlabel( ,grid labsize(small) angle(45))
graph export "intervention_ts.png", replace

g FX_patch_inverse = 1/FX_patch
g target_inverse = 1/target

// exchange rate over time
la var FX_patch_inverse "Pound/Dollar Exchange Rate"
la var target_inverse "Official Target"
tsline FX_patch_inverse target_inverse , graphregion(color(white)) /// note("Data from Financial Times, patched with GFD.") 
xtitle("") ytitle("") title("Pound/Dollar Exchange Rate Over Time (With Official Target)" , size(med)) xlabel( ,grid labsize(small) angle(45)) legend(pos(6))
graph export "fx_ts.png" , replace

/////////////////// Begin Making Tables (for Paper and Appendix) /////////////////////
tsset timevar
g depmonth = (year == 1967)*(month ==11)

global nodep = "if date != 2881 & date != 2880"
replace FX_growth = . if date == 2881 | date == 2880 // outliers due to depreciation in '67
replace int_base_frac = . if date == 2881 | date == 2880
// we also do this so that *lags* of any relevant variables show up as missing 

global nodepmonth = "if depmonth == 0" 
global basic = "i.dow i.month i.year"
global long  = "i.dow i.month i.year del* fcast_revision_1mo "
global vlong  = "l.FX_growth l2.FX_growth del* fcast_revision_1mo change* i.dow i.month i.year " 

la var int_base_frac "Intervention"
la var FX_growth "FX Growth"

////////////////// Table 1: OLS  vs. IV: basic controls, Distance Instrument Only
eststo clear
eststo ols1, title("Full Sample"): 		reg FX_growth int_base_frac $basic $nodep , r
eststo iv1, title("Full Sample"): 		ivregress 2sls FX_growth (int_base_frac = l.logdist_sq)  $basic $nodep,   vce(robust)  
eststo iv2, title("Pre-Devaluation"): 	ivregress 2sls FX_growth (int_base_frac = l.logdist_sq) $basic $nodep & date < 2880 , r
eststo iv3, title("Post-Devaluation"): 	ivregress 2sls FX_growth (int_base_frac = l.logdist_sq) $basic $nodep & date > 2881, r
eststo iv4, title("Drop Nov. '67"):  	ivregress 2sls FX_growth (int_base_frac = l.logdist_sq) $basic $nodepmonth ,  r
eststo iv5, title("After 1958"): 		ivregress 2sls FX_growth (int_base_frac = l.logdist_sq) $basic $nodep & year > 1958, r

esttab ols* iv* using "olsIV_distonly.tex", ///
mtitles fragment label replace booktabs  se b(2) drop(*year* *month* *dow* *con* ) 

/////////////// TABLE 2: First Stages, Distance Instrument Only /////////////////////
g logdist_sq_lagged_and_labelled = (log(l.FX_patch/l.target)*100)^2*sign(l.target - l.FX_patch) // flip sign!
// Also put in ppt. 
// This is now the lagged, squared distance from exchange rate target (in ppt.)
la var logdist_sq_lagged_and_labelled "Lagged, Squared Distance from Target"
// others are ok: 
eststo clear
eststo ols2, title("Full Sample"): 		reg int_base_frac logdist_sq_lagged_and_labelled   $nodep,  vce(robust)  
eststo ols3, title("Pre-Devaluation"): 	reg int_base_frac logdist_sq_lagged_and_labelled   $nodep & date < 2880 , r
eststo ols4, title("Post-Devaluation"): reg int_base_frac logdist_sq_lagged_and_labelled   $nodep & date > 2881, r
eststo ols5, title("Drop Nov. '67"):  	reg int_base_frac logdist_sq_lagged_and_labelled   $nodepmonth ,  r
eststo ols6, title("After 1958"): 		reg int_base_frac logdist_sq_lagged_and_labelled   $nodep & year > 1958, r

// Tables for writeup: First Stages
esttab ols*  using "olsIV_first_distonly.tex", ///
mtitles fragment label replace booktabs  se r2 b(2)  scalars(F) 


///////////////// Table 3: Summary Statistics Table  ///////////
// Idea: mean and standard deviation of dependant variable (FX growth), intervention (Qt), 
// and the "distance from target" 
g logdist = -log(l.FX_patch/l.target)*100 
g non_forward_int_dollar_sales   = -non_forward_intervention
la var non_forward_int_dollar_sales "Dollar Sales (in Millions USD)"
// Report Mean and Standard Deviation
sum FX_growth logdist non_forward_int_dollar_sales int_base_frac $nodep
// copied by hand (three sig figs)


///////////////////////////////////////////////////////////////////////////////////////////////
////// APPENDIX FIGURES AND TABLES   //////////// /////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////////////////////////

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
///////////// A1: TABLE 4 IV + add'l Controls		//////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

eststo clear // Second stages: vlong controls
eststo iv0, title("Full Sample"):    		  quietly regress FX_growth int_base_frac $vlong $nodep, r
eststo iv1, title("Full Sample"):    		  quietly ivregress 2sls FX_growth (int_base_frac = l.logdist_sq) $vlong $nodep, r
eststo iv2, title("Pre-Devaluation"): 		  quietly ivregress 2sls FX_growth (int_base_frac = l.logdist_sq) $vlong $nodep & date < 2880 , r
eststo iv3, title("Post-Devaluation"): 		  quietly ivregress 2sls FX_growth (int_base_frac = l.logdist_sq) $vlong $nodep & date > 2881, r
eststo iv4, title("Drop Nov. '67"):  		  quietly ivregress 2sls FX_growth (int_base_frac = l.logdist_sq) $vlong $nodepmonth ,  r
eststo iv5, title("After 1958"): 			  quietly ivregress 2sls FX_growth (int_base_frac = l.logdist_sq) $vlong $nodep & year > 1958, r
esttab iv* using "olsIV_logdist_vlong_distonly.tex", ///
mtitles label replace booktabs  se b(2) drop(*year* *month* *dow* change* *con* ) fragment


////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
///////////// A2: Splitting Sample + USING LEVEL of Exchange rate //////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

g LVL_INSTRUMENT = -log(l.FX_patch)*100
la var LVL_INSTRUMENT "Logged, Lagged FX Lvl."

g LVL_INSTRUMENT_POST = -log(l.FX_patch)*afterdeval*100
la var LVL_INSTRUMENT_POST "Logged, Lagged FX Lvl (after Devaluation)."

global predep  = "if date < 2880"
global postdep = "if date > 2881"

/////////////// A2: TABLE 5: OLS  vs. IV: basic controls ----- SPLITTING SAMPLE + USING LEVELS 
eststo clear
eststo ols1a, title("OLS"): 		quietly reg FX_growth int_base_frac $basic $nodep , r
eststo ols1b, title("OLS (Pre)"): 	quietly reg FX_growth int_base_frac $basic $predep , r
eststo ols1c, title("OLS (Post)"): 	quietly reg FX_growth int_base_frac $basic $postdep , r

eststo iv1, title("IV: Level"):		   quietly ivregress 2sls FX_growth (int_base_frac = LVL_INSTRUMENT LVL_INSTRUMENT_POST)  	  $basic $nodep ,   vce(robust)  
eststo iv2, title("IV: Level (Pre)"):  quietly ivregress 2sls FX_growth (int_base_frac = LVL_INSTRUMENT)  $basic $predep ,   vce(robust)  
eststo iv3, title("IV: Level (Post)"): quietly ivregress 2sls FX_growth (int_base_frac = LVL_INSTRUMENT) $basic $postdep ,   vce(robust)  

esttab ols* iv* using "olsIV_splitsample_levels.tex", ///
mtitles fragment label replace booktabs  se b(2) drop(*year* *month* *dow* *con* ) 

/////////////// A2: TABLE 6: First Stages  ----- SPLITTING SAMPLE + USING LEVELS
// OLS  vs. IV: basic controls
eststo clear
eststo ols1, title("Level "): 	   quietly reg int_base_frac LVL_INSTRUMENT LVL_INSTRUMENT_POST   $nodep , r
eststo ols2, title("Level (Pre)"):  quietly reg int_base_frac LVL_INSTRUMENT   $predep , r
eststo ols3, title("Level (Post)"): quietly reg int_base_frac LVL_INSTRUMENT   $postdep , r

esttab ols*  using "olsIV_first_splitsample_levels.tex", ///
mtitles fragment label replace booktabs  se r2 b(2)  scalars(F) 

/////////////// A2: TABLE 7 Distance IV + Controls ----- SPLITTING SAMPLE
eststo clear // Second stages: vlong controls
eststo iv0, title("Full Sample"):    		  quietly regress FX_growth int_base_frac $vlong $nodep, r
eststo iv1, title("Full Sample"):    		  quietly ivregress 2sls FX_growth (int_base_frac = LVL_INSTRUMENT LVL_INSTRUMENT_POST) $vlong $nodep , r
eststo iv2, title("Pre Dep."):  		  	  quietly ivregress 2sls FX_growth (int_base_frac = LVL_INSTRUMENT) $vlong $predep ,  r 
eststo iv3, title("Post Dep."): 			  quietly ivregress 2sls FX_growth (int_base_frac = LVL_INSTRUMENT) $vlong $postdep , r

esttab iv* using "olsIV_logdist_vlong_withGold_splitsample_levels.tex", ///
mtitles label replace booktabs  se b(2) drop(*year* *month* *dow* change* *con* ) fragment


////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
///////////// A3: Splitting Sample + USING dollar sales to measure intervention  /////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

/////////////// A3: TABLE 8: Table 1 with DOLLAR SALES not scaled by M0
eststo clear
eststo ols1, title("Full Sample"): 		reg FX_growth non_forward_int_dollar_sales $basic $nodep , r
eststo iv1, title("Full Sample"): 		ivregress 2sls FX_growth (non_forward_int_dollar_sales = l.logdist_sq)  $basic $nodep,   vce(robust)  
eststo iv2, title("Pre-Devaluation"): 	ivregress 2sls FX_growth (non_forward_int_dollar_sales = l.logdist_sq) $basic $nodep & date < 2880 , r
eststo iv3, title("Post-Devaluation"): 	ivregress 2sls FX_growth (non_forward_int_dollar_sales = l.logdist_sq) $basic $nodep & date > 2881, r
eststo iv4, title("Drop Nov. '67"):  	ivregress 2sls FX_growth (non_forward_int_dollar_sales = l.logdist_sq) $basic $nodepmonth ,  r
eststo iv5, title("After 1958"): 		ivregress 2sls FX_growth (non_forward_int_dollar_sales = l.logdist_sq) $basic $nodep & year > 1958, r
esttab ols* iv* using "olsIV_distonly_dollarsales.tex", ///
mtitles fragment label replace booktabs  se b(4) drop(*year* *month* *dow* *con* ) 

/////////////// A3: TABLE 9: Table 2 with DOLLAR SALES: First Stages
eststo clear
eststo ols2, title("Full Sample"): 		reg non_forward_int_dollar_sales logdist_sq_lagged_and_labelled   $nodep,  vce(robust)  
eststo ols3, title("Pre-Devaluation"): 	reg non_forward_int_dollar_sales logdist_sq_lagged_and_labelled   $nodep & date < 2880 , r
eststo ols4, title("Post-Devaluation"): reg non_forward_int_dollar_sales logdist_sq_lagged_and_labelled   $nodep & date > 2881, r
eststo ols5, title("Drop Nov. '67"):  	reg non_forward_int_dollar_sales logdist_sq_lagged_and_labelled   $nodepmonth ,  r
eststo ols6, title("After 1958"): 		reg non_forward_int_dollar_sales logdist_sq_lagged_and_labelled   $nodep & year > 1958, r

esttab ols*  using "olsIV_first_distonly_dollarsales.tex", ///
mtitles fragment label replace booktabs  se r2 b(2)  scalars(F) 


////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
///////////// B: Holiday w/LASSO forecast counterfactuals: Tables 10 and 11  ////////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// from 11d_figures* (Jake W.) 
* https://ideas.repec.org/c/boc/bocode/s458458.html
* ssc install lassopack // may need to run this line to install this package.
// we used v1.4.1 

tsset timevar
// define "training" sample: no holidays
global noHolSamp2 =  "if date != 2881 & date != 2880 & holiday_mkt_open == 0" 

// generate some variables for Lasso to potentially choose: trendbreak in the time trend?
g timevarAfter = timevar*afterdeval 
// allow saturdays to have special dummy during friday/saturday reported lumping period? 
g sat_lumping = (dow == 6)*(date > -1722)*(date <1751)
// package doesn't accept factor notation: make dummies for seasonal adjustments 
qui tabulate month , g(MO_)
qui tabulate dow , g(DOW_)
// YR_2 and del_fedfunds don't play nicely together in Lasso:
qui tabulate year if year > 1953 ,  g(YR2_) 

// first get predictions for FX_growth: 
lasso2 FX_growth timevar timevarAfter afterdeval sat_lumping ///
l(1/10).int_base_frac l(1/10).FX_growth  l(1/10).logdist_sq  /// 
l(1/10).del* l(1/10).fcast_revision_1mo l(1/10).GoldFracM0 ///
depmonth MO_*  DOW_* YR2_* change* $noHolSamp2 , adaptive  // 

// Different information criteria in principle could choose different lambdas: 
predict lasso_FX_growth_fcast_ebic , xb lic(ebic) // Get Forecasts for FX growth from lasso
predict lasso_FX_growth_fcast_bic  , xb lic(bic) 
predict lasso_FX_growth_fcast_aic  , xb lic(aic) 
predict lasso_FX_growth_fcast_aicc , xb lic(aicc)
corr lasso_FX_growth_fcast*
// aic and aicc are identical. EBIC and BIC almost identical. -- still true after updating lassopack
drop lasso_FX_growth_fcast_aicc

lasso2 int_base_frac timevar timevarAfter afterdeval sat_lumping ///
l(1/10).int_base_frac l(1/10).FX_growth  l(1/10).logdist_sq  ///
l(1/10).del* l(1/10).fcast_revision_1mo l(1/10).GoldFracM0 ///
depmonth MO_*  DOW_* YR2_* change* $noHolSamp2 , adaptive // long

predict lasso_int_base_frac_fcast_ebic , xb lic(ebic) // Get Forecasts for intervention from lasso
predict lasso_int_base_frac_fcast_bic  , xb lic(bic)  
predict lasso_int_base_frac_fcast_aic  , xb lic(aic)  
predict lasso_int_base_frac_fcast_aicc , xb lic(aicc) 
corr lasso_int_base_frac_fcast* 
drop lasso_int_base_frac_fcast_aicc // lasso_int_base_frac_fcast_ebic

// generate forecast errors: FX --- Added EBIC results (default)
g lasso_FX_growth_error_ebic = FX_growth - lasso_FX_growth_fcast_ebic
g lasso_FX_growth_error_bic = FX_growth - lasso_FX_growth_fcast_bic
g lasso_FX_growth_error_aic = FX_growth - lasso_FX_growth_fcast_aic
// generate forecast errors: INT --- Added EBIC results (default)
g lasso_int_base_frac_error_ebic = int_base_frac - lasso_int_base_frac_fcast_ebic
g lasso_int_base_frac_error_bic = int_base_frac - lasso_int_base_frac_fcast_bic
g lasso_int_base_frac_error_aic = int_base_frac - lasso_int_base_frac_fcast_aic

la var lasso_FX_growth_fcast_aic "AIC Forecast"
la var lasso_FX_growth_fcast_bic "BIC Forecast"
la var lasso_FX_growth_fcast_ebic "EBIC Forecast"

la var lasso_int_base_frac_error_aic "Intervention: AIC" 
la var lasso_int_base_frac_error_bic "Intervention: BIC"
la var lasso_int_base_frac_error_ebic "Intervention: EBIC"

/////////////// B: TABLE 10 lasso results with all IC
eststo clear 
eststo ols0a, title("BIC"): reg lasso_FX_growth_error_bic lasso_int_base_frac_error_bic $noHolSamp2   , r // All non-holidays
eststo ols0b, title("EBIC"): reg lasso_FX_growth_error_ebic lasso_int_base_frac_error_ebic $noHolSamp2   , r // All non-holidays
eststo ols0c, title("AIC"): reg lasso_FX_growth_error_aic lasso_int_base_frac_error_aic $noHolSamp2   , r // All non-holidays

eststo ols1a, title("BIC"): reg lasso_FX_growth_error_bic lasso_int_base_frac_error_bic if holiday_mkt_open ==1 , r // Holidays
eststo ols1b, title("EBIC"): reg lasso_FX_growth_error_ebic lasso_int_base_frac_error_ebic if holiday_mkt_open ==1 , r // Holidays
eststo ols1c, title("AIC"): reg lasso_FX_growth_error_aic lasso_int_base_frac_error_aic if holiday_mkt_open ==1 , r // Holidays

esttab ols* using "policy_rule_regressions_lassoRegs_all_IC.tex", ///
mtitles label replace booktabs fragment r2 se b(2) drop(*cons*)  star(+ 0.10 * 0.05 ** .01 *** .001) // adds 10% level

/////////////// B: TABLE 11 lasso results with all IC by subsample period
eststo clear 
eststo ols2a, title("BIC"): reg lasso_FX_growth_error_bic lasso_int_base_frac_error_bic if holiday_mkt_open ==1 & date < 2880, r // Holidays, pre deval
eststo ols2b, title("EBIC"): reg lasso_FX_growth_error_ebic lasso_int_base_frac_error_ebic if holiday_mkt_open ==1 & date < 2880, r // Holidays, pre deval
eststo ols2c, title("AIC"): reg lasso_FX_growth_error_aic lasso_int_base_frac_error_aic if holiday_mkt_open ==1 & date < 2880, r // Holidays, pre deval

eststo ols4a, title("BIC"): reg lasso_FX_growth_error_bic lasso_int_base_frac_error_bic if holiday_mkt_open ==1 & year > 1958, r // Holidays, post 1958
eststo ols4b, title("EBIC"): reg lasso_FX_growth_error_ebic lasso_int_base_frac_error_ebic if holiday_mkt_open ==1 & year > 1958, r // Holidays, post 1958
eststo ols4c, title("AIC"): reg lasso_FX_growth_error_aic lasso_int_base_frac_error_aic if holiday_mkt_open ==1 & year > 1958, r // Holidays, post 1958

eststo ols5a, title("BIC"): reg lasso_FX_growth_error_bic lasso_int_base_frac_error_bic if holiday_mkt_open ==1 & year > 1958 & date < 2880, r // Holidays, pre-Deval, post 1958
eststo ols5b, title("EBIC"): reg lasso_FX_growth_error_ebic lasso_int_base_frac_error_ebic if holiday_mkt_open ==1 & year > 1958 & date < 2880, r // Holidays, pre-Deval, post 1958
eststo ols5c, title("AIC"): reg lasso_FX_growth_error_aic lasso_int_base_frac_error_aic if holiday_mkt_open ==1 & year > 1958 & date < 2880, r // Holidays, pre-Deval, post 1958
// Too few holidays post-devaluation for meaningful analysis (<<20)
esttab ols* using "policy_rule_regressions_lassoRegs_split_all_IC.tex", ///
mtitles label replace booktabs fragment r2 se b(2) drop(*cons*)  star(+ 0.10 * 0.05 ** .01 *** .001) // adds 10% level


/////////////// D: FIGURE 3: simulation results
use benchmark_pt0_pt14_pt75_n5000, clear // simulated data as described in Appendix D
local NN = _N+1
set obs `NN'
g decay_monthly_ppt = (1-decay_monthly)*100
foreach var of varlist _all {
	replace `var' = 0 in `NN'
	}
sort decay_monthly_ppt
g time = _n
tsset time
g OurEstimate = -.05

twoway 	(rarea IVest_p5 IVest_p95 decay_monthly_ppt, color(gs8) ) ///
	(line IVest OurEstimate decay_monthly_ppt, xtitle("Implied Monthly Decay Rate (Percentage Points)") ///
	ytitle("Estimated Effect of Intervention") lcolor(black red) lwidth(medthick thick) ///
	lpattern(solid longdash)  legend(order(2 "Mean Simulated IV Estimate" 1 "90% Distribution of Simulated IV Estimates (p5-p95 range)" 3 "IV Estimate from actual data (for reference)" ) position(6)) ///
	title("Bias in IV When True Effect is Zero As Mean Reversion Increases" , size(medlarge))) //
graph export benchmark_pt0_pt14_pt75_n5000_shade.png, replace

